@@ -17,7 +17,7 @@ class AdvancedQReader(PandasQReader):
             self._buffer.skip()
             length = self._buffer.get_int()
             symbols = self._buffer.get_symbols(length)
-            series = pandas.Series([s.decode('utf-8') for s in symbols])
+            series = pandas.Series([s.decode('utf-8') for s in symbols], dtype=str)
             series.meta = MetaData(qtype=qtype)
             return series
         else:
