@@ -1,6 +1,7 @@
 import time
 import threading
 import os
+import sys
 
 import numpy
 from qpython.qconnection import QConnection
@@ -27,6 +28,7 @@ class MonitorThread(threading.Thread):
     def __init__(self):
         super(MonitorThread, self).__init__()
         self.pool = ConnectionPool()
+        self.daemon = True
 
     def run(self):
         while True:
